@@ -32,25 +32,25 @@ class HOTPDevice(Device):
 
         *BigIntegerField*: The next counter value to expect. (Initial: 0)
     """
-    key = models.CharField(max_length=80, validators=[hex_validator()], default=lambda: random_hex(20), help_text=u"A hex-encoded secret key of up to 40 bytes.")
-    digits = models.PositiveSmallIntegerField(choices=[(6,6), (8,8)], default=6, help_text=u"The number of digits to expect in a token.")
-    tolerance = models.PositiveSmallIntegerField(default=5, help_text=u"The number of missed tokens to tolerate.")
-    counter = models.BigIntegerField(default=0, help_text=u"The next counter value to expect.")
+    key = models.CharField(max_length=80, validators=[hex_validator()], default=lambda: random_hex(20), help_text="A hex-encoded secret key of up to 40 bytes.")
+    digits = models.PositiveSmallIntegerField(choices=[(6, 6), (8, 8)], default=6, help_text="The number of digits to expect in a token.")
+    tolerance = models.PositiveSmallIntegerField(default=5, help_text="The number of missed tokens to tolerate.")
+    counter = models.BigIntegerField(default=0, help_text="The next counter value to expect.")
 
     class Meta(Device.Meta):
-        verbose_name = u"HOTP device"
+        verbose_name = "HOTP device"
 
     @property
     def bin_key(self):
         """
         The secret key as a binary string.
         """
-        return unhexlify(self.key)
+        return unhexlify(self.key.encode())
 
     def verify_token(self, token):
         try:
             token = int(token)
-        except StandardError:
+        except Exception:
             verified = False
         else:
             key = self.bin_key
